#
# spec file for package spicetify-cli
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sname cli
%define binname spicetify
Name:           spicetify-cli
Version:        2.40.7
Release:        1.1
Summary:        Command-line tool to customize Spotify client
License:        LGPL-2.1-or-later
URL:            https://spicetify.app/
Source0:        %{sname}-%{version}.tar.zst
Source1:        vendor.tar.gz
BuildRequires:  golang(API) >= 1.24

%description
Command-line tool to customize the official Spotify client

%prep
%autosetup -a1 -n %{sname}-%{version}

%build
go build -mod=vendor -buildmode=pie -ldflags="-X 'main.version=%{version}'"
printf "#!/bin/sh\n%{_libdir}/%{name}/%{binname} \"\$@\"" > ./shortcut

%install
install -Dm755 shortcut %{buildroot}%{_bindir}/%{binname}
install -Dm755 %{sname} %{buildroot}%{_libdir}/%{name}/%{binname}
cp -r Themes Extensions CustomApps jsHelper globals.d.ts css-map.json %{buildroot}%{_libdir}/%{name}

find %{buildroot}%{_libdir}/%{name}/ -type f -executable | grep -v %{name}/%{binname} | xargs chmod a-x

%files
%{_bindir}/%{binname}
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/*
%license LICENSE
%doc README.md

%changelog
* Mon May 12 2025 Jan Kužílek <jan.kuzilek@suse.com>
- Update to version 2.40.7:
  * feat(lyrics-plus/translator): inject internals when using netease
  * feat(lyrics-plus/netease): implement below-mode for netease (#3404)
  * chore: `error` -> `warning`
  * chore: change message in preprocess
  * chore(deps): bump golang.org/x/net from 0.39.0 to 0.40.0 (#3399)
  * feat(preprocess): expose graphql defs from every js file
  * fix: correct minor typo when version is invalid (#3393)
* Sun Apr 27 2025 Jan Kužílek <jan.kuzilek@suse.com>
- Update to version 2.40.5:
  * build: bump golang to `1.24.2`
  * fix: `frameworkResourcesPath` for macOS
  * chore: change names
* Wed Apr 23 2025 Jan Kužílek <jan.kuzilek@suse.com>
- Update to version 2.40.4:
  * fix(preprocess): add missing `--spice-main-elevated`
* Wed Apr 23 2025 Jan Kužílek <jan.kuzilek@suse.com>
- Update to version 2.40.2:
  * fix(preprocess): check if `> 0` for context menu
* Wed Apr 23 2025 Jan Kužílek <jan.kuzilek@suse.com>
- Update to version 2.40.1:
  * feat(preprocess): merge `windows` & `linux` case
  * chore(preprocess): remove `currentFile`
  * feat: more logging shown to users
  * fix: remove unused appending
* Tue Apr 22 2025 Jan Kužílek <jan.kuzilek@suse.com>
- Remove unnecessary BuildRequires, update to go1.24
* Tue Apr 22 2025 Jan Kužílek <jan.kuzilek@suse.com>
- Update to version 2.40.0:
  * chore(preprocess): remove unnecessary checking for dir
  * feat: add support for embedded xpui in v8 snapshot
  * fix: add support for Spotify `1.2.62`
  * chore(deps): bump golang.org/x/net from 0.38.0 to 0.39.0 (#3368)
  * fix: add `$lineClamp` key to styled components processing (#3370)
  * fix: update `resizeHost` selector & `Topbar` button styling
  * chore(deps): bump golang.org/x/net from 0.37.0 to 0.38.0 (#3359)
  * chore(cmd/apply): correct grammar
  * chore(deps): bump golang.org/x/net from 0.35.0 to 0.37.0 (#3342)
  * fix(wrapper): left topbar icons & run scroll fix on `1.2.56` and lower
  * docs(lyrics-plus): update readme to warn Genius is disabled (#3344)
* Thu Mar 13 2025 jan.kuzilek@suse.com
- Update to version 2.39.5:
  * fix: remove bypass flag after checking for admin
  * fix(popupLyrics): update view in system tray mode (#3330)
  * feat(types): add `dark_vibrant` to `colorExtractor` (#3321)
  * feat(popupLyrics): implement lyrics caching & Musixmatch token refresh (#3328)
  * style: run `fmt` on `isAdmin` pkg
  * fix: split `isAdmin` to platform files
  * fix(preprocess): add css for height on apps pages (1.2.57+)
  * feat: disallow running spicetify as admin/root
  * fix(lyrics-plus): properly set height on main view (#3322)
* Sat Feb 15 2025 jan.kuzilek@suse.com
- Update to version 2.39.3:
  * fix(lyrics-plus): properly check for `none` value in trans lang (#3312)
  * feat(lyrics-plus): optimize convert performance & improve code quality (#3311)
  * feat(lyrics-plus): translation display individual copy implementation (#3308)
  * chore(deps): bump golang.org/x/net from 0.34.0 to 0.35.0 (#3309)
  * fix(lyrics-plus): fix lyrics transition effect issue (#3305)
* Wed Feb 12 2025 jan.kuzilek@suse.com
- Update to version 2.39.2:
  * fix(preprocess): remove checking spotify ver
  * chore(lyrics-plus/OptionsMenu): change displayed text
  * fix: re-render lyrics div when `Translation Display` is changed
  * feat(lyrics-plus): allow to change display of lyrics translation (#3297)
  * feat(lyrics-plus): add select language translation for Musixmatch provider (#3288)
  * feat: patch only `xpui.js` on Spotify `1.2.57` and higher
  * fix(homeConfig): make the regex work on more versions
  * feat(wrapper): add smooth scrolling for Spotify 1.2.56
  * fix(expFeatures): make it work on versions without `RemoteConfigDebugAPI`
  * feat: migrate state folders
  * chore(deps): bump github.com/mattn/go-colorable from 0.1.13 to 0.1.14 (#3267)
  * chore(deps): bump golang.org/x/net from 0.33.0 to 0.34.0 (#3265)
* Tue Feb  4 2025 jan.kuzilek@suse.com
- Update to version 2.38.9:
  * fix(homeConfig): make it work on Spotify `1.2.56`
  * fix(GetStateFolder): put files in specific state folder
  * feat(trashbin): add a working export button (#3268)
  * refactor: change folder location for `Backup` and `Extracted` (#3282)
  * fix: use new PlatformAPI in exp features
  * fix(keyboardShortcut): change called function to skip song (#3273)
* Fri Dec 27 2024 jan.kuzilek@suse.com
- Update to version 2.38.7:
  * chore: remove console log
  * fix: indefinitely wait for necessary chunks
  * chore(deps): bump golang.org/x/net from 0.32.0 to 0.33.0 (#3242)
* Thu Dec 19 2024 jan.kuzilek@suse.com
- Update to version 2.38.6:
  * fix(wrapper): set `priority` to 1 in `OnChunksLoaded`
  * feat: add ability to change cors proxy server
  * feat(css-map): add classes for `navLinks` in `1.2.53`
  * chore(deps): bump golang.org/x/net from 0.31.0 to 0.32.0 (#3236)
  * chore(deps): bump actions/attest-build-provenance from 1 to 2 (#3235)
  * fix(update): use `GetSpotifyPath` from `cmd`
  * fix(shuffle+): update GraphQL handling (#3229)
* Mon Dec  9 2024 jan.kuzilek@suse.com
- Update to version 2.38.5:
  * fix(new-releases): stop close button propagation (#3224)
  * chore(deps): bump golang.org/x/net from 0.30.0 to 0.31.0 (#3218)
  * style(trashbin): update used icon (#3212)
  * feat(fullAppDisplay): seekable progress and aligned buttons (#3168)
  * chore(deps): bump golang.org/x/net from 0.29.0 to 0.30.0 (#3196)
  * feat(css-map): add header 1.2.49 classnames (#3208)
  * chore: remove stale labeler (#3207)
  * fix: svg url in readme.md (#3204)
  * chore(sidebarConfig): make phrasing more os inclusive (#3190)
* Sat Sep 28 2024 jan.kuzilek@suse.com
- Update to version 2.38.4:
  * fix(preprocess): add new regex to catch variable names for context menu
  * chore(sidebarConfig): change how msg is shown
  * fix(new-releases): use hardcoded `queryArtistDiscographyAll` def (#3166)
  * fix(apply): check for old global navbar existence
* Wed Sep 11 2024 jan.kuzilek@suse.com
- Update to version 2.38.3:
  * feat(topbar): cross-version classname support (#3162)
  * feat(wrapper): relay on webpack's `OnChunksLoadedRuntimeModule`
* Mon Sep  9 2024 jan.kuzilek@suse.com
- Update to version 2.38.2:
  * fix(block-updates): block update folder on `macOS`
  * fix(preprocess/contextmenu): fallback when regex doesn't find candicates
  * fix(block-updates): go back one folder
* Sun Sep  8 2024 jan.kuzilek@suse.com
- Update to version 2.38.0:
  * fix(homeConfig): check if `uri` exists too
  * feat(preprocess/contextmenu): simplify matches
  * fix(apply): remove 4th submatch since it's unnecessary
  * fix(navlinks): add support for `1.2.46`'s global navbar
  * feat(apply): add ability to call multiple functions to one file
  * fix(home-config): support up to 1.2.45 (#3161)
  * feat(sidebarConfig): disable functionality when Global navbar is used
  * fix(apply): move expFeatures regex to the `insertExpFeatures`
  * chore(preprocess): remove console log
  * fix(preprocess/contextmenu): adapt regex for `1.2.46`
  * chore(wrapper): change check for `os_name` to `osx`
  * fix(InitPaths): check for `Apps` folder
  * fix(reddit/tabBar): showing context menu in `More`
  * fix(new-releases): use `PlatformAPI` to fetch podcasts
  * fix(sidebarConfig): remove remaining legacy stuff
  * feat(sidebarConfig): remove support for pre-Library X
  * feat: remove support for pre-Library X UI
  * feat: rename `block-updates` to `spotify-updates`
  * feat(wrapper): set buttons heigh for 1.2.45 and older for Library X
  * feat(cmd): add `block-updates` cmd to block spotify updates
  * revert: check for spotify.exe existence instead of app folder
  * chore(deps): bump golang.org/x/net from 0.28.0 to 0.29.0 (#3156)
  * fix(css-map): just fixing a typo (#3152)
* Thu Aug 29 2024 jan.kuzilek@suse.com
- Update to version 2.37.7:
  * fix(wrapper): sanitize text content to remove all strings
  * fix(wrapper): ignore chunks in strings
  * fix(wrapper): fire `platformLoaded` event later
  * feat(css-map): map `search-searchCategory-carouselButtonVisible` (#3146)
  * feat(popupLyrics): add lrclib provider (#3133)
* Sun Aug 25 2024 jan.kuzilek@suse.com
- Update to version 2.37.4:
  * fix(wrapper/webpack): do not return while webpack is loading
  * fix(wrapper): wait until all modules loaded (#3143)
  * fix(preprocess): match more special characters for `_platform`
  * fix(workflows): only run build & linter on main branches (#3137)
  * fix(wrapper): replace find string for `Slider` component (#3134)
  * fix(preprocess): adapt `_platform` regex for `1.2.44`
  * style(lyrics-plus): adjust lyric animation in `karaoke` mode (#3130)
  * chore(deps): bump golang.org/x/net from 0.27.0 to 0.28.0 (#3129)
  * fix(lyrics-plus/genius): remove `encodeURIComponent` (#3131)
  * fix(new-releases): use `50000` as a limit
* Sun Aug 18 2024 Jan Kužílek <jan.kuzilek@suse.com>
- Initial package, version 2.37.1
